# coding: utf-8

from dynaconf import settings

print(settings.MYSQL_HOST)  # noqa
print(settings.MYSQL_PASSWD)  # noqa
print(settings.EXAMPLE)  # noqa
print(settings.WORKS)  # noqa
